#romanization
class AmharicTranslitrator:
    def transliterate (norm):
        norm = norm.replace("hwa", "ኋ")
        norm = norm.replace("hua", "ኋ")
        norm = norm.replace("hie", "ሄ")
        norm = norm.replace("ha", "ሀ")
        norm = norm.replace("hu", "ሁ")
        norm = norm.replace("hi", "ሂ")
        norm = norm.replace("he", "ሄ")
        norm = norm.replace("ho", "ሆ")
        norm = norm.replace("lwa", "ሏ")
        norm = norm.replace("lua", "ሏ")
        norm = norm.replace("le", "ለ")
        norm = norm.replace("lu", "ሉ")
        norm = norm.replace("li", "ሊ")
        norm = norm.replace("la", "ላ")
        norm = norm.replace("le", "ሌ")
        norm = norm.replace("lo", "ሎ")
        norm = norm.replace("l", "ል")
        norm = norm.replace("mwa", "ሟ")
        norm = norm.replace("mua", "ሟ")
        norm = norm.replace("mie", "ሜ")
        norm = norm.replace("me", "መ")
        norm = norm.replace("mu", "ሙ")
        norm = norm.replace("mi", "ሚ")
        norm = norm.replace("ma", "ማ")
        norm = norm.replace("mo", "ሞ")
        norm = norm.replace("m", "ም")
        norm = norm.replace("rwa", "ሯ")
        norm = norm.replace("rua", "ሯ")
        norm = norm.replace("rie", "ሬ")
        norm = norm.replace("re", "ረ")
        norm = norm.replace("ru", "ሩ")
        norm = norm.replace("ri", "ሪ")
        norm = norm.replace("ra", "ራ")
        norm = norm.replace("ro", "ሮ")
        norm = norm.replace("r", "ር")
        norm = norm.replace("swa", "ሷ")
        norm = norm.replace("sua", "ሷ")
        norm = norm.replace("sie", "ሴ")
        norm = norm.replace("se", "ሰ")
        norm = norm.replace("su", "ሱ")
        norm = norm.replace("si", "ሲ")
        norm = norm.replace("sa", "ሳ")
        norm = norm.replace("so", "ሶ")
        norm = norm.replace("shwa", "ሿ")
        norm = norm.replace("shua", "ሿ")
        norm = norm.replace("she", "ሸ")
        norm = norm.replace("shu", "ሹ")
        norm = norm.replace("shi", "ሺ")
        norm = norm.replace("sha", "ሻ")
        norm = norm.replace("sho", "ሾ")
        norm = norm.replace("sh", "ሺ")
        norm = norm.replace("qwa", "ቋ")
        norm = norm.replace("qua", "ቋ")
        norm = norm.replace("qie", "ቄ")
        norm = norm.replace("qe", "ቀ")
        norm = norm.replace("qu", "ቁ")
        norm = norm.replace("qi", "ቂ")
        norm = norm.replace("qa", "ቃ")
        norm = norm.replace("qo", "ቆ")
        norm = norm.replace("q", "ቅ")
        norm = norm.replace("bwa", "ቧ")
        norm = norm.replace("bua", "ቧ")
        norm = norm.replace("bie", "ቤ")
        norm = norm.replace("be", "በ")
        norm = norm.replace("bu", "ቡ")
        norm = norm.replace("bi", "ቢ")
        norm = norm.replace("ba", "ባ")
        norm = norm.replace("bo", "ቦ")
        norm = norm.replace("b", "ብ")
        norm = norm.replace("vwa", "ቯ")
        norm = norm.replace("vua", "ቯ")
        norm = norm.replace("vie", "ቬ")
        norm = norm.replace("ve", "ቨ")
        norm = norm.replace("vu", "ቩ")
        norm = norm.replace("vi", "ቪ")
        norm = norm.replace("va", "ቫ")
        norm = norm.replace("vo", "ቮ")
        norm = norm.replace("v", "ቭ")
        norm = norm.replace("twa", "ቷ")
        norm = norm.replace("tua", "ቷ")
        norm = norm.replace("tie", "ቴ")
        norm = norm.replace("te", "ተ")
        norm = norm.replace("tu", "ቱ")
        norm = norm.replace("ti", "ቲ")
        norm = norm.replace("ta", "ታ")
        norm = norm.replace("to", "ቶ")
        norm = norm.replace("chwa", "ቿ")
        norm = norm.replace("chua", "ቿ")
        norm = norm.replace("chie", "ቼ")
        norm = norm.replace("che", "ቸ")
        norm = norm.replace("chu", "ቹ")
        norm = norm.replace("chi", "ቺ")
        norm = norm.replace("cha", "ቻ")
        norm = norm.replace("cho", "ቾ")
        norm = norm.replace("gnwa", "ኟ")
        norm = norm.replace("gnua", "ኟ")
        norm = norm.replace("gne", "ኘ")
        norm = norm.replace("gnu", "ኙ")
        norm = norm.replace("gni", "ኚ")
        norm = norm.replace("gna", "ኛ")
        norm = norm.replace("gno", "ኞ")
        norm = norm.replace("gn", "ኝ")
        norm = norm.replace("nwa", "ኗ")
        norm = norm.replace("nua", "ኗ")
        norm = norm.replace("nie", "ኔ")
        norm = norm.replace("ne", "ነ")
        norm = norm.replace("nu", "ኑ")
        norm = norm.replace("ni", "ኒ")
        norm = norm.replace("na", "ና")
        norm = norm.replace("no", "ኖ")
        norm = norm.replace("n", "ን")
        norm = norm.replace("kwa", "ኳ")
        norm = norm.replace("kua", "ኳ")
        norm = norm.replace("kie", "ኬ")
        norm = norm.replace("ke", "ከ")
        norm = norm.replace("ku", "ኩ")
        norm = norm.replace("ki", "ኪ")
        norm = norm.replace("ka", "ካ")
        norm = norm.replace("ko", "ኮ")
        norm = norm.replace("k", "ክ")
        norm = norm.replace("wie", "ዌ")
        norm = norm.replace("we", "ወ")
        norm = norm.replace("wu", "ው")
        norm = norm.replace("wi", "ዊ")
        norm = norm.replace("wa", "ዋ")
        norm = norm.replace("wo", "ወ")
        norm = norm.replace("w", "ው")
        norm = norm.replace("zwa", "ዟ")
        norm = norm.replace("zua", "ዟ")
        norm = norm.replace("zie", "ዜ")
        norm = norm.replace("ze", "ዘ")
        norm = norm.replace("zu", "ዙ")
        norm = norm.replace("zi", "ዚ")
        norm = norm.replace("za", "ዛ")
        norm = norm.replace("zo", "ዞ")
        norm = norm.replace("zhwa", "ዧ")
        norm = norm.replace("zhua", "ዧ")
        norm = norm.replace("zhie", "ዤ")
        norm = norm.replace("zhe", "ዠ")
        norm = norm.replace("zhu", "ዡ")
        norm = norm.replace("zhi", "ዢ")
        norm = norm.replace("zha", "ዣ")
        norm = norm.replace("zho", "ዦ")
        norm = norm.replace("zh", "ዥ")
        norm = norm.replace("z", "ዝ")
        norm = norm.replace("ye", "የ")
        norm = norm.replace("yu", "ዩ")
        norm = norm.replace("yi", "ዪ")
        norm = norm.replace("ya", "ያ")
        norm = norm.replace("yo", "ዮ")
        norm = norm.replace("y", "ይ")
        norm = norm.replace("dwa", "ዷ")
        norm = norm.replace("dua", "ዷ")
        norm = norm.replace("die", "ዴ")
        norm = norm.replace("de", "ደ")
        norm = norm.replace("du", "ዱ")
        norm = norm.replace("di", "ዲ")
        norm = norm.replace("da", "ዳ")
        norm = norm.replace("do", "ዶ")
        norm = norm.replace("d", "ድ")
        norm = norm.replace("jwa", "ጇ")
        norm = norm.replace("jua", "ጇ")
        norm = norm.replace("je", "ጀ")
        norm = norm.replace("ju", "ጁ")
        norm = norm.replace("ji", "ጂ")
        norm = norm.replace("ja", "ጃ")
        norm = norm.replace("jo", "ጆ")
        norm = norm.replace("j", "ጅ")
        norm = norm.replace("gwa", "ጓ")
        norm = norm.replace("gua", "ጓ")
        norm = norm.replace("gie", "ጌ")        
        norm = norm.replace("ge", "ገ")
        norm = norm.replace("gu", "ጉ")
        norm = norm.replace("gi", "ጊ")
        norm = norm.replace("ga", "ጋ")
        norm = norm.replace("go", "ጎ")
        norm = norm.replace("g", "ግ")
        norm = norm.replace("chwa", "ጯ")
        norm = norm.replace("chua", "ጯ")
        norm = norm.replace("che", "ጨ")
        norm = norm.replace("chu", "ጩ")
        norm = norm.replace("chi", "ጪ")
        norm = norm.replace("cha", "ጫ")
        norm = norm.replace("cho", "ጮ")
        norm = norm.replace("ch", "ች")
        norm = norm.replace("h", "ህ")
        norm = norm.replace("tswa", "ጿ")
        norm = norm.replace("tsua", "ጿ")
        norm = norm.replace("tsie", "ፄ")
        norm = norm.replace("tse", "ፀ")
        norm = norm.replace("tsu", "ፁ")
        norm = norm.replace("tsi", "ፂ")
        norm = norm.replace("tsa", "ፃ")
        norm = norm.replace("tso", "ፆ")
        norm = norm.replace("ts", "ፅ")
        norm = norm.replace("t", "ት")
        norm = norm.replace("s", "ስ")
        norm = norm.replace("fwa", "ፏ")
        norm = norm.replace("fua", "ፏ")
        norm = norm.replace("fie", "ፌ")
        norm = norm.replace("fe", "ፈ")
        norm = norm.replace("fu", "ፉ")
        norm = norm.replace("fi", "ፊ")
        norm = norm.replace("fa", "ፋ")
        norm = norm.replace("fo", "ፎ")
        norm = norm.replace("f", "ፍ")
        norm = norm.replace("pwa", "ፗ")
        norm = norm.replace("pua", "ፗ")
        norm = norm.replace("pie", "ፔ")
        norm = norm.replace("pe", "ፐ")
        norm = norm.replace("pu", "ፑ")
        norm = norm.replace("pi", "ፒ")
        norm = norm.replace("pa", "ፓ")
        norm = norm.replace("po", "ፖ")
        norm = norm.replace("p", "ፕ")
        norm = norm.replace("a", "አ")
        norm = norm.replace("u", "ኡ")
        norm = norm.replace("i", "ኢ")
        norm = norm.replace("e", "እ")
        norm = norm.replace("o", "ኦ")
        norm = norm.replace(".", "፡፡")
        norm = norm.replace(";", "፤")
        norm = norm.replace(":", "፥")
        norm = norm.replace(",", "፣")
        return norm


from amseg.amharicSegmenter import AmharicSegmenter
from amseg.amharicNormalizer import AmharicNormalizer
from amseg.amharicRomanizer import AmharicRomanizer
from amseg.amharicTranslitrator import AmharicTranslitrator


import re
from typing import List

class AmharicSegmenter:
    SENT_PUNC =  []
    WORD_PUNC =  []
    def __init__(self, sent_punct, word_punct):
        if sent_punct:
            self.SENT_PUNC = sent_punct
        else:
            self.SENT_PUNC = ["።","፥","፨","::","፡፡","?","!"]
        if word_punct:
            self.WORD_PUNC = word_punct
        else:
            self.WORD_PUNC =  ["።","፥","፤","፨","?","!",":","፡","፦","፣"]
            
    def amharic_tokenizer(self, text: str):
        """
        Tokenizer based on space character and different Amharic punctuation marksonly.
        """
        tokens = []
        word = ""
        index = -1
        previchar = ''
        for index, char in enumerate(text):
            if char == " ":
                if len(word) > 0:
                    start_position = index - len(word)
                    tokens.append(word)

                word = ""
            elif char in self.WORD_PUNC:
                if len(word) > 0 and previchar != char:
                    start_position = index - len(word)
                    tokens.append(word)
                    word = ""
                previchar = char
                word += char

            else:
                word += char
        # increment for last token in sentence if not followed by whitespace
        index += 1
        if len(word) > 0:
            start_position = index - len(word)
            tokens.append(word)
        return tokens
    
    def find_all(self, punct, text):
        return [i + len(punct)-1 for i in range(len(text)) if text.startswith(punct, i)]
        

    def tokenize_sentence(self, text: str):
        text = re.sub("\n", "።",text)
        text = re.sub("\s+", " ",text)
        #text = re.sub("\r", "።",text)
        #text = re.sub("\n\r", "።",text)
        tokenized_text = []
        idxs = [-1] # see below, used to start the next sentence after the index of the sentence segmenter
        for sep in self.SENT_PUNC:
            idx = text.find(sep)
            if idx > 0:
                allidx = self.find_all(sep, text)
                for idx in allidx:
                    idxs.append(idx)
        idxs = sorted(idxs)
        if len(idxs) ==1:
            tokenized_text.append(text)# just one sentence without the punctuation marks
        for i in range(len(idxs)-1): # 
            tokenized_text.append(text[idxs[i]+1:idxs[i+1]+1].strip())
        return tokenized_text

    # apply sentence tokenization
    def window_lines(self, line, window):
        '''
        Some models require the length of the sentence to be moderate, so to avvoid shorter sentences, append some using some windowing technique
        '''
        try:
            text = re.sub("\s+", " ",line)
            sentences = [s for s in self.tokenize_sentence(text) if len(s) >= 6]
            windowed_sentences = []
            for snt in range(len(sentences)):
                windowed_sentences.append(" ".join(sentences[snt: snt + window]))
            return windowed_sentences
        except:
            # print(f"Could not parse line \n{line}\n")
            return []
        
    # windwoing with segmented sentence
    def window_sents(self, sentences, window):
        '''
        Some models require the length of the sentence to be moderate, so to avvoid sgorter sentences, append some using some windowing technique
        '''
        try:
            windowed_sentences = []
            for snum in range(len(sentences)):
                windowed_sentences.append(" ".join(sentences[snum: snum + window]))
            return windowed_sentences
        except:
            # print(f"Could not parse line \n{line}\n")
            return []




#romanization
class AmharicRomanizer:
    def romanize (norm):
        norm = norm.replace("ሀ", "ha")
        norm = norm.replace("ሁ", "hu")
        norm = norm.replace("ሂ", "hi")
        norm = norm.replace("ሃ", "hā")
        norm = norm.replace("ሄ", "hé")
        norm = norm.replace("ህ", "h")
        norm = norm.replace("ሆ", "ho")
        norm = norm.replace("ለ", "la")
        norm = norm.replace("ሉ", "lu")
        norm = norm.replace("ሊ", "li")
        norm = norm.replace("ላ", "lā")
        norm = norm.replace("ሌ", "lé")
        norm = norm.replace("ል", "l")
        norm = norm.replace("ሎ", "lo")
        norm = norm.replace("ሏ", "lwa")
        norm = norm.replace("ሐ", "ḥa")
        norm = norm.replace("ሑ", "ḥu")
        norm = norm.replace("ሒ", "ḥi")
        norm = norm.replace("ሓ", "ḥā")
        norm = norm.replace("ሔ", "ḥé")
        norm = norm.replace("ሕ", "ḥ")
        norm = norm.replace("ሖ", "ḥo")
        norm = norm.replace("ሗ", "hwa")
        norm = norm.replace("መ", "mä")
        norm = norm.replace("ሙ", "mu")
        norm = norm.replace("ሚ", "mi")
        norm = norm.replace("ማ", "mā")
        norm = norm.replace("ሜ", "mé")
        norm = norm.replace("ም", "m")
        norm = norm.replace("ሞ", "mo")
        norm = norm.replace("ሟ", "mwa")
        norm = norm.replace("ሠ", "śa")
        norm = norm.replace("ሡ", "śu")
        norm = norm.replace("ሢ", "śi")
        norm = norm.replace("ሣ", "śā")
        norm = norm.replace("ሤ", "śé")
        norm = norm.replace("ሥ", "ś")
        norm = norm.replace("ሦ", "śo")
        norm = norm.replace("ሧ", "śwa")
        norm = norm.replace("ረ", "ra")
        norm = norm.replace("ሩ", "ru")
        norm = norm.replace("ሪ", "ri")
        norm = norm.replace("ራ", "rā")
        norm = norm.replace("ሬ", "ré")
        norm = norm.replace("ር", "r")
        norm = norm.replace("ሮ", "ro")
        norm = norm.replace("ሯ", "rwa")
        norm = norm.replace("ሰ", "sa")
        norm = norm.replace("ሱ", "su")
        norm = norm.replace("ሲ", "si")
        norm = norm.replace("ሳ", "sā")
        norm = norm.replace("ሴ", "sé")
        norm = norm.replace("ስ", "sə")
        norm = norm.replace("ሶ", "so")
        norm = norm.replace("ሷ", "swa")
        norm = norm.replace("ሸ", "ša")
        norm = norm.replace("ሹ", "šu")
        norm = norm.replace("ሺ", "ši")
        norm = norm.replace("ሻ", "šā")
        norm = norm.replace("ሼ", "šé")
        norm = norm.replace("ሽ", "š")
        norm = norm.replace("ሾ", "šo")
        norm = norm.replace("ሿ", "šwa")
        norm = norm.replace("ቀ", "qa")
        norm = norm.replace("ቁ", "qu")
        norm = norm.replace("ቂ", "qi")
        norm = norm.replace("ቃ", "qā")
        norm = norm.replace("ቄ", "qé")
        norm = norm.replace("ቅ", "q")
        norm = norm.replace("ቆ", "qo")
        norm = norm.replace("ቈ", "qwa")
        norm = norm.replace("ቊ", "qwu")
        norm = norm.replace("ቋ", "qwi")
        norm = norm.replace("ቌ", "qwā")
        norm = norm.replace("ቍ", "qwe")
        norm = norm.replace("በ", "ba")
        norm = norm.replace("ቡ", "bu")
        norm = norm.replace("ቢ", "bi")
        norm = norm.replace("ባ", "bā")
        norm = norm.replace("ቤ", "bé")
        norm = norm.replace("ብ", "b")
        norm = norm.replace("ቦ", "bo")
        norm = norm.replace("ቧ", "bwa")
        norm = norm.replace("ቨ", "va")
        norm = norm.replace("ቩ", "vu")
        norm = norm.replace("ቪ", "vi")
        norm = norm.replace("ቫ", "vā")
        norm = norm.replace("ቬ", "vé")
        norm = norm.replace("ቭ", "v")
        norm = norm.replace("ቮ", "vo")
        norm = norm.replace("ቯ", "vwa")
        norm = norm.replace("ተ", "ta")
        norm = norm.replace("ቱ", "tu")
        norm = norm.replace("ቲ", "ti")
        norm = norm.replace("ታ", "tā")
        norm = norm.replace("ቴ", "té")
        norm = norm.replace("ት", "t")
        norm = norm.replace("ቶ", "to")
        norm = norm.replace("ቷ", "twa")
        norm = norm.replace("ቸ", "ča")
        norm = norm.replace("ቹ", "ču")
        norm = norm.replace("ቺ", "či")
        norm = norm.replace("ቻ", "čā")
        norm = norm.replace("ቼ", "čé")
        norm = norm.replace("ች", "č")
        norm = norm.replace("ቾ", "čo")
        norm = norm.replace("ቿ", "čwa")
        norm = norm.replace("ኀ", "ẖa")
        norm = norm.replace("ኁ", "ẖu")
        norm = norm.replace("ኂ", "ẖi")
        norm = norm.replace("ኃ", "ẖā")
        norm = norm.replace("ኄ", "ẖé")
        norm = norm.replace("ኅ", "ẖ")
        norm = norm.replace("ኆ", "ẖo")
        norm = norm.replace("ኈ", "ẖwa")
        norm = norm.replace("ኊ", "ẖwi")
        norm = norm.replace("ኋ", "ẖwā")
        norm = norm.replace("ኌ", "ẖwé")
        norm = norm.replace("ኍ", "ẖwe")
        norm = norm.replace("ነ", "na")
        norm = norm.replace("ኑ", "nu")
        norm = norm.replace("ኒ", "ni")
        norm = norm.replace("ና", "nā")
        norm = norm.replace("ኔ", "né ")
        norm = norm.replace("ን", "n")
        norm = norm.replace("ኖ", "no")
        norm = norm.replace("ኗ", "nwa")
        norm = norm.replace("ኘ", "ña")
        norm = norm.replace("ኙ", "ñu")
        norm = norm.replace("ኚ", "ñi")
        norm = norm.replace("ኛ", "ñā")
        norm = norm.replace("ኜ", "ñé")
        norm = norm.replace("ኝ", "ñ")
        norm = norm.replace("ኞ", "ño")
        norm = norm.replace("ኟ", "ñwa")
        norm = norm.replace("አ", "ʾa")
        norm = norm.replace("ኡ", "ʾu")
        norm = norm.replace("ኢ", "ʾi")
        norm = norm.replace("ኣ", "ʾā")
        norm = norm.replace("ኤ", "ʾé")
        norm = norm.replace("እ", "ʾe")
        norm = norm.replace("ኦ", "ʾo")
        norm = norm.replace("ኧ", "ă")
        norm = norm.replace("ከ", "ka")
        norm = norm.replace("ኩ", "ku")
        norm = norm.replace("ኪ", "ki")
        norm = norm.replace("ካ", "kā")
        norm = norm.replace("ኬ", "ké")
        norm = norm.replace("ክ", "k")
        norm = norm.replace("ኮ", "ko")
        norm = norm.replace("ኰ", "kwa")
        norm = norm.replace("ኲ", "kwi")
        norm = norm.replace("ኳ", "kwā")
        norm = norm.replace("ኴ", "kwé")
        norm = norm.replace("ኵ", "kwe")
        norm = norm.replace("ኸ", "xa")
        norm = norm.replace("ኹ", "xu")
        norm = norm.replace("ኺ", "xi")
        norm = norm.replace("ኻ", "xā")
        norm = norm.replace("ኼ", "xé")
        norm = norm.replace("ኽ", "x")
        norm = norm.replace("ኾ", "xo")
        norm = norm.replace("ወ", "wa")
        norm = norm.replace("ዉ", "wu")
        norm = norm.replace("ዊ", "wi")
        norm = norm.replace("ዋ", "wā")
        norm = norm.replace("ዌ", "wé")
        norm = norm.replace("ው", "w")
        norm = norm.replace("ዎ", "wo")
        norm = norm.replace("ዐ", "ʻa")
        norm = norm.replace("ዑ", "ʻu")
        norm = norm.replace("ዒ", "ʻi")
        norm = norm.replace("ዓ", "ʻā")
        norm = norm.replace("ዔ", "ʻé")
        norm = norm.replace("ዕ", "ʻe")
        norm = norm.replace("ዖ", "ʻo")
        norm = norm.replace("ዘ", "za")
        norm = norm.replace("ዙ", "zu")
        norm = norm.replace("ዚ", "zi")
        norm = norm.replace("ዛ", "zā")
        norm = norm.replace("ዜ", "zé")
        norm = norm.replace("ዝ", "z")
        norm = norm.replace("ዞ", "zo")
        norm = norm.replace("ዟ", "zwa")
        norm = norm.replace("ዠ", "ža")
        norm = norm.replace("ዡ", "žu")
        norm = norm.replace("ዢ", "ži")
        norm = norm.replace("ዣ", "žā")
        norm = norm.replace("ዤ", "žé")
        norm = norm.replace("ዥ", "ž")
        norm = norm.replace("ዦ", "žo")
        norm = norm.replace("ዧ", "žwa")
        norm = norm.replace("የ", "ya")
        norm = norm.replace("ዩ", "yu")
        norm = norm.replace("ዪ", "yi")
        norm = norm.replace("ያ", "yā")
        norm = norm.replace("ዬ", "yé")
        norm = norm.replace("ይ", "y")
        norm = norm.replace("ዮ", "yo")
        norm = norm.replace("ደ", "da")
        norm = norm.replace("ዱ", "du")
        norm = norm.replace("ዲ", "di")
        norm = norm.replace("ዳ", "dā")
        norm = norm.replace("ዴ", "dé")
        norm = norm.replace("ድ", "d")
        norm = norm.replace("ዶ", "do")
        norm = norm.replace("ዷ", "dwa")
        norm = norm.replace("ጀ", "ǧa")
        norm = norm.replace("ጁ", "ǧu")
        norm = norm.replace("ጂ", "ǧi")
        norm = norm.replace("ጃ", "ǧā")
        norm = norm.replace("ጄ", "ǧé")
        norm = norm.replace("ጅ", "ǧ")
        norm = norm.replace("ጆ", "ǧo")
        norm = norm.replace("ጇ", "ǧwa")
        norm = norm.replace("ገ", "ga")
        norm = norm.replace("ጉ", "gu")
        norm = norm.replace("ጊ", "gi")
        norm = norm.replace("ጋ", "gā")
        norm = norm.replace("ጌ", "gé")
        norm = norm.replace("ግ", "g")
        norm = norm.replace("ጎ", "go")
        norm = norm.replace("ጐ", "gwa")
        norm = norm.replace("ጒ", "gwi")
        norm = norm.replace("ጓ", "gwā")
        norm = norm.replace("ጔ", "gwé")
        norm = norm.replace("ጕ", "gwe")
        norm = norm.replace("ጠ", "ṭa")
        norm = norm.replace("ጡ", "ṭu")
        norm = norm.replace("ጢ", "ṭi")
        norm = norm.replace("ጣ", "ṭā")
        norm = norm.replace("ጤ", "ṭé")
        norm = norm.replace("ጥ", "ṭ")
        norm = norm.replace("ጦ", "ṭo")
        norm = norm.replace("ጧ", "ṭwā")
        norm = norm.replace("ጨ", "ċa")
        norm = norm.replace("ጩ", "ċu")
        norm = norm.replace("ጪ", "ċi")
        norm = norm.replace("ጫ", "ċā")
        norm = norm.replace("ጬ", "ċé")
        norm = norm.replace("ጭ", "ċ")
        norm = norm.replace("ጮ", "ċo")
        norm = norm.replace("ጯ", "ċwā")
        norm = norm.replace("ጰ", "p̣a")
        norm = norm.replace("ጱ", "p̣u")
        norm = norm.replace("ጲ", "p̣i")
        norm = norm.replace("ጳ", "p̣ā")
        norm = norm.replace("ጴ", "p̣é")
        norm = norm.replace("ጵ", "p̣")
        norm = norm.replace("ጶ", "p̣o")
        norm = norm.replace("ጷ", "p̣wa")
        norm = norm.replace("ጸ", "ṣa")
        norm = norm.replace("ጹ", "ṣu")
        norm = norm.replace("ጺ", "ṣi")
        norm = norm.replace("ጻ", "ṣā")
        norm = norm.replace("ጼ", "ṣé")
        norm = norm.replace("ጽ", "ṣ")
        norm = norm.replace("ጾ", "ṣo")
        norm = norm.replace("ጿ", "ṣwā")
        norm = norm.replace("ፀ", "ṡa")
        norm = norm.replace("ፁ", "ṡu")
        norm = norm.replace("ፂ", "ṡi")
        norm = norm.replace("ፃ", "ṡā")
        norm = norm.replace("ፄ", "ṡé")
        norm = norm.replace("ፅ", "ṡ")
        norm = norm.replace("ፆ", "ṡo")
        norm = norm.replace("ፈ", "fa")
        norm = norm.replace("ፉ", "fu")
        norm = norm.replace("ፊ", "fi")
        norm = norm.replace("ፋ", "fā")
        norm = norm.replace("ፌ", "fé")
        norm = norm.replace("ፍ", "f")
        norm = norm.replace("ፎ", "fo")
        norm = norm.replace("ፏ", "fwā")
        norm = norm.replace("ፐ", "pa")
        norm = norm.replace("ፑ", "pu")
        norm = norm.replace("ፒ", "pi")
        norm = norm.replace("ፓ", "pā")
        norm = norm.replace("ፔ", "pé")
        norm = norm.replace("ፕ", "p")
        norm = norm.replace("ፖ", "po")
        norm = norm.replace("ፗ", "pwa")
        norm = norm.replace("፡", " ")
        norm = norm.replace("።", ".")
        norm = norm.replace("፡፡", ".")
        norm = norm.replace("፤", ";")
        norm = norm.replace("፥", ":")
        norm = norm.replace("፣", ",")
        norm = norm.replace("፧", ".")
        norm = norm.replace("፩", "1")
        norm = norm.replace("፪", "2")
        norm = norm.replace("፫", "3")
        norm = norm.replace("፬", "4")
        norm = norm.replace("፭", "5")
        norm = norm.replace("፮", "6")
        norm = norm.replace("፯", "7")
        norm = norm.replace("፰", "8")
        norm = norm.replace("፱", "9")
        norm = norm.replace("፲", "10")
        norm = norm.replace("፳", "20")
        norm = norm.replace("፴", "30")
        norm = norm.replace("፵", "40")
        norm = norm.replace("፶", "50")
        norm = norm.replace("፷", "60")
        norm = norm.replace("፸", "70")
        norm = norm.replace("፹", "80")
        norm = norm.replace("፺", "90")
        norm = norm.replace("፻", "100")
        norm = norm.replace("\n", "\n")
        return norm


import re
class AmharicNormalizer:
	def normalize (norm):
			norm = norm.replace("ሀ", "ሃ")
			norm = norm.replace("ሐ", "ሃ")
			norm = norm.replace("ሓ", "ሃ")
			norm = norm.replace("ኅ", "ሃ")
			norm = norm.replace("ኻ", "ሃ")
			norm = norm.replace("ኃ", "ሃ")
			norm = norm.replace("ዅ", "ሁ")
			norm = norm.replace("ሗ", "ኋ")
			norm = norm.replace("ኁ", "ሁ")
			norm = norm.replace("ኂ", "ሂ")
			norm = norm.replace("ኄ", "ሄ");
			norm = norm.replace("ዄ", "ሄ");
			norm = norm.replace("ኅ", "ህ");
			norm = norm.replace("ኆ", "ሆ");
			norm = norm.replace("ሑ", "ሁ");
			norm = norm.replace("ሒ", "ሂ");
			norm = norm.replace("ሔ", "ሄ");
			norm = norm.replace("ሕ", "ህ");
			norm = norm.replace("ሖ", "ሆ");
			norm = norm.replace("ኾ", "ሆ");
			norm = norm.replace("ሠ", "ሰ");
			norm = norm.replace("ሡ", "ሱ");
			norm = norm.replace("ሢ", "ሲ");
			norm = norm.replace("ሣ", "ሳ");
			norm = norm.replace("ሤ", "ሴ");
			norm = norm.replace("ሥ", "ስ");
			norm = norm.replace("ሦ", "ሶ");
			norm = norm.replace("ዐ", "አ");
			norm = norm.replace("ዑ", "ኡ");
			norm = norm.replace("ዒ", "ኢ");
			norm = norm.replace("ዓ", "አ");
			norm = norm.replace("ኣ", "አ");
			norm = norm.replace("ዔ", "ኤ");
			norm = norm.replace("ዕ", "እ");
			norm = norm.replace("ዖ", "ኦ");
			norm = norm.replace("ፀ", "ጸ");
			norm = norm.replace("ፁ", "ጹ");
			norm = norm.replace("ጺ", "ፂ");
			norm = norm.replace("ጻ", "ፃ");
			norm = norm.replace("ጼ", "ፄ");
			norm = norm.replace("ፅ", "ጽ");
			norm = norm.replace("ፆ", "ጾ");
			norm = norm.replace("ሼ", "ሸ");
			norm = norm.replace("ሺ", "ሽ");
			norm = norm.replace("ዲ", "ድ");
			norm = norm.replace("ጄ", "ጀ");
			norm = norm.replace("ጂ", "ጅ");
			norm = norm.replace("ዉ", "ው");
			norm = norm.replace("ዎ", "ወ");
			norm = norm.replace("ዴ", "ደ");
			norm = norm.replace("ቼ", "ቸ");
			norm = norm.replace("ቺ", "ች");
			norm = norm.replace("ዬ", "የ");
			norm = norm.replace("ዪ", "ይ");
			norm = norm.replace("ጬ", "ጨ");
			norm = norm.replace("ጪ", "ጭ");
			norm = norm.replace("ኜ", "ኘ");
			norm = norm.replace("ኚ", "ኝ");
			norm = norm.replace("ዤ", "ዠ");
			norm = norm.replace("ዢ", "ዥ");
			
			norm=re.sub('(ሉ[ዋአ])','ሏ',norm)
			norm=re.sub('(ሙ[ዋአ])','ሟ',norm)
			norm=re.sub('(ቱ[ዋአ])','ቷ',norm)
			norm=re.sub('(ሩ[ዋአ])','ሯ',norm)
			norm=re.sub('(ሱ[ዋአ])','ሷ',norm)
			norm=re.sub('(ሹ[ዋአ])','ሿ',norm)
			norm=re.sub('(ቁ[ዋአ])','ቋ',norm)
			norm=re.sub('(ቡ[ዋአ])','ቧ',norm)
			norm=re.sub('(ቹ[ዋአ])','ቿ',norm)
			norm=re.sub('(ሁ[ዋአ])','ኋ',norm)
			norm=re.sub('(ኑ[ዋአ])','ኗ',norm)
			norm=re.sub('(ኙ[ዋአ])','ኟ',norm)
			norm=re.sub('(ኩ[ዋአ])','ኳ',norm)
			norm=re.sub('(ዙ[ዋአ])','ዟ',norm)
			norm=re.sub('(ጉ[ዋአ])','ጓ',norm)
			norm=re.sub('(ደ[ዋአ])','ዷ',norm)
			norm=re.sub('(ጡ[ዋአ])','ጧ',norm)
			norm=re.sub('(ጩ[ዋአ])','ጯ',norm)
			norm=re.sub('(ጹ[ዋአ])','ጿ',norm)
			norm=re.sub('(ፉ[ዋአ])','ፏ',norm)
			norm=re.sub('[ቊ]','ቁ',norm) 
			norm=re.sub('[ኵ]','ኩ',norm)
			norm=re.sub('\s+',' ',norm)
			
			return norm



from setuptools import setup, Extension
def readme():
    with open('README.rst') as f:
        return f.read()
setup(
  name = 'amseg',         # Amharic Sentence segmentation, tokenization and normalization tools
  packages = ['amseg'],   # Chose the same as "name"
  version = '1.4',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'This is an Amharic document segmentation and normalization tool',   # Give a short description about your library
  long_description=readme(),
  author = 'Seid Muhie Yimam',                   # Type in your name
  author_email = 'seid.muhie.yimam@uni-hamburg.de',      # Type in your E-Mail
  url = 'https://github.com/uhh-lt/amharicprocessor',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/uhh-lt/amharicprocessor/archive/rehistoryfs/tags/v_14.tar.gz',    # I explain this later on
  keywords = ['Amharic', 'Amharic sentence splitter', 'Amharic document normalizer', 'Amharic Latin to Fidel Transliteration'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
         # 'validators',
        #  'beautifulsoup4',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
    'Programming Language :: Python :: 3.7',
    'Programming Language :: Python :: 3.7',
  ],
)
